@@ -1,3 +1,4 @@
+# _*_ coding: utf-8 _*_
 import os
 import re
 import sys
@@ -41,7 +42,7 @@ def humanize(us):
     if us >= min: return "%sm" % round(us/min, 1)
     if us >= sec: return "%ss" % round(us/sec, 1)
     if us >= ms: return "%sms" % round(us/ms, 1)
-    return "%sus" % us
+    return u"%sμs" % us
 
 
 def noop(*args, **kwargs):
@@ -74,12 +75,12 @@ def debug(name):
         colors the output,
         mimicks pythons print() function
         """
-        return "  \033[9{0}m{1} \033[3{0}m\033[90m{2}\033[3{0}m +{3}\033[0m".format(
+        return u"  \033[9{0}m{1} \033[3{0}m\033[90m{2}\033[3{0}m +{3}\033[0m".format(
                c, name, fmt, humanize(us))
 
     def plain(fmt, us):
-        return "{} {} {} +{}".format(to_utc_string(time.time()),
-                                    name, fmt, humanize(us))
+        return u"{} {} {} +{}".format(to_utc_string(time.time()),
+                                      name, fmt, humanize(us))
 
     def printable(*args, **kwargs):
         sep = kwargs.get('sep', ' ')
